//*********************************************************************//
//Function to transmit data in Manchester Code, according to IEEE 802.3//
//definition ("1" is "LtoH" and "0" is "HtoL").                        //
//Transmission speed is indicated by "baud_tx", either 5000bps or      //
//2500bps. It is converted into time (half period time) and stored in  //
//"semiperiod" by a simple "if" statement. Math calculations have been //
//avoided to preserve the microcontroller's memory.                    //
//The full routine sends 20 "1" followed by "0" (frame synchronism),   //
//then 8 "ADDRESS" bits, followed by "1" and "0" (byte spacer), doing  //
//the same procedure with "DATA" and "CRC".                            //
//Microcontroller Xtal: 20MHz - No Watch Dog Timer - No Power Up Timer.//
//*********************************************************************//

//Definitions
int semiperiod;
int i_tx;
short b_tx;
//End of definitions

void one()
{
   output_low(PIN_A0);        //Function "one"; generates a Manchester
   delay_us(semiperiod);      //Code "1" (transition "Low to High").
   output_high(PIN_A0);
   delay_us(semiperiod);
}

void zero()
{
   output_high(PIN_A0);       //Function "zero"; generates a Manchester
   delay_us(semiperiod);      //Code "0" (transition "High to Low").
   output_low(PIN_A0);
   delay_us(semiperiod);
}   

void tx(int a_tx)
{
   for(i_tx=1;i_tx<=8;++i_tx)
   {
     b_tx=shift_left(&a_tx,1,0);//"a_tx" contents are shifted to "b_tx"
     if(b_tx==1) one();       //one bit at a time; if "1" calls function
     if(b_tx==0) zero();      //"one", if "0" calls function "zero".
   }
   one();                     //Byte spacer: "1" followed by "0".
   zero();
}

void mc_tx(long baud_tx, int addr_tx, int data_tx, int crc_tx)
{
   if(baud_tx==5000)          //"Semiperiod" definition according to
   semiperiod=100;            //the bit rate (baud_tx). It is fixed
   else                       //to the two possible values instead
   semiperiod=200;            //of calculating it to save memory.

   for(i_tx=1;i_tx<=20;++i_tx)
   one();                     //20 initial "1" of the TX frame
   zero();                    //followed by "0".
   
   tx(addr_tx);               //"ADDRESS" (byte) transmission.
      
   tx(data_tx);               //"DATA" (byte) transmission.
      
   tx(crc_tx);                //"CRC" (byte) transmission.
      
   output_low(PIN_A0);        //"Idle" state (between frames).
}
