#include "Manchester_Link_TX.h"
#include "MAN_TX.c"

//********************************************************************//
//Main program; here is where the user programs the microcontroller to//
//set what data is going to be transmitted using the "mc_tx" function //
//(specified in the #include <MAN_TX.c>).                             //
//The bit rate can be any of 2 values: 5000bps or 2500bps; ADDRESS,   //
//DATA and CRC are bytes, according to the Manchester Code frame      //
//definition. All these 4 variables must be sent to the "mc_tx"       //
//function to work. Additionally, this function must be called every  //
//10 milliseconds or less for the RF link to work; if the main program//
//takes longer than that (e.g. reading an external sensor), then the  //
//function should be called at least a couple of times, spaced by 10  //
//milliseconds or less, to guarantee a reliable transmission, before  //
//returning to the main program routine.                              //
//Check the MAN_TX.c file to learn about its variables, since they    //
//should be reserved and the same names not used in this main program.//
//This example uses the PIC16F628A @ 20MHz, and PIN A2 (pin 1) to set //
//the bit rate (low: 2500bps; high: 5000bps)and PIN A3 (pin 2) to set //
//the test LED on the receiver ON (low: ON; high: blinking).          //
//This demonstrates how to program the TX unit and send data to the   //
//TX function. For the purpose of this example, ADDRESS will be fixed //
//and CRC = DATA, as the simplest form of data accuracy validation.   //
//The user can use any possible combination, with the only restriction//
//that these 3 variables must be 1 byte long each; if a longer data   //
//must be transmitted, this can be done in succesive transmissions or //
//assigning the high byte to DATA and the low byte to CRC.            //
//Microcontroller Xtal: 20MHz - No Watch Dog Timer - No Power Up Timer//
//********************************************************************//

//Definitions
long baud;
int address;
int data;
int crc;
int timer=0;
//End of definitions

void main()
{
   setup_timer_0(RTCC_INTERNAL|RTCC_DIV_1);
   setup_timer_1(T1_DISABLED);
   setup_timer_2(T2_DISABLED,0,1);
   setup_comparator(NC_NC_NC_NC);
   setup_vref(FALSE);

   while(1)                            //Infinite loop.
   {
      if(input(PIN_A2)==0)             //Bit rate selection:
      baud=2500;                       //PIN A2 low = 2500;
      else                             //PIN A2 high = 5000.
      baud=5000;
      
      address=15;                      //Fixed value.
      
      if(input(PIN_A3)==0)             //If PIN A3 is low,
      data=1;                          //DATA will be "1" (LED ON).
      else                             //If PIN A3 is high,
      {                                //a timer (byte) is started.
         timer=timer+1;                //Each cycle increments by 1.
         if(timer<=127)                //Half of the time the LED
         data=0;                       //will be OFF (DATA = "0");
         if(timer>=128)                //the second half (from 128
         data=1;                       //to 255) will be ON.
      }                                //Timer returns to 0 after 255.
      
      crc=data;                        //CRC is set equal to DATA.
      
//The user may replace the previous code (whitin the "While" loop)
//with any other code, just making sure that the 4 variables, BAUD,
//ADDDRESS, DATA and CRC contain the information intended to be
//transmitted. This information may include static or variable data,
//such as the output of a sensor, the result of an A/D converter, etc.
      
      mc_tx(baud, address, data, crc); //"mc_tx" function is called.
      
      delay_ms(1);                     //Waits 1 millisecond to
   }                                   //start again.
}
